from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Storage
import win32more.Windows.Storage.Streams
import win32more.Windows.System
import win32more.Windows.Win32.System.WinRT
class Buffer(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Storage.Streams.IBuffer
    _classid_ = 'Windows.Storage.Streams.Buffer'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 1:
            super().__init__(move=win32more.Windows.Storage.Streams.Buffer.Create(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def Create(cls: win32more.Windows.Storage.Streams.IBufferFactory, capacity: UInt32) -> win32more.Windows.Storage.Streams.Buffer: ...
    @winrt_mixinmethod
    def get_Capacity(self: win32more.Windows.Storage.Streams.IBuffer) -> UInt32: ...
    @winrt_mixinmethod
    def get_Length(self: win32more.Windows.Storage.Streams.IBuffer) -> UInt32: ...
    @winrt_mixinmethod
    def put_Length(self: win32more.Windows.Storage.Streams.IBuffer, value: UInt32) -> Void: ...
    @winrt_classmethod
    def CreateCopyFromMemoryBuffer(cls: win32more.Windows.Storage.Streams.IBufferStatics, input: win32more.Windows.Foundation.IMemoryBuffer) -> win32more.Windows.Storage.Streams.Buffer: ...
    @winrt_classmethod
    def CreateMemoryBufferOverIBuffer(cls: win32more.Windows.Storage.Streams.IBufferStatics, input: win32more.Windows.Storage.Streams.IBuffer) -> win32more.Windows.Foundation.MemoryBuffer: ...
    Capacity = property(get_Capacity, None)
    Length = property(get_Length, put_Length)
class ByteOrder(Enum, Int32):
    LittleEndian = 0
    BigEndian = 1
class DataReader(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[ContextManagerProtocol]
    default_interface: win32more.Windows.Storage.Streams.IDataReader
    _classid_ = 'Windows.Storage.Streams.DataReader'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 1:
            super().__init__(move=win32more.Windows.Storage.Streams.DataReader.CreateDataReader(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateDataReader(cls: win32more.Windows.Storage.Streams.IDataReaderFactory, inputStream: win32more.Windows.Storage.Streams.IInputStream) -> win32more.Windows.Storage.Streams.DataReader: ...
    @winrt_mixinmethod
    def get_UnconsumedBufferLength(self: win32more.Windows.Storage.Streams.IDataReader) -> UInt32: ...
    @winrt_mixinmethod
    def get_UnicodeEncoding(self: win32more.Windows.Storage.Streams.IDataReader) -> win32more.Windows.Storage.Streams.UnicodeEncoding: ...
    @winrt_mixinmethod
    def put_UnicodeEncoding(self: win32more.Windows.Storage.Streams.IDataReader, value: win32more.Windows.Storage.Streams.UnicodeEncoding) -> Void: ...
    @winrt_mixinmethod
    def get_ByteOrder(self: win32more.Windows.Storage.Streams.IDataReader) -> win32more.Windows.Storage.Streams.ByteOrder: ...
    @winrt_mixinmethod
    def put_ByteOrder(self: win32more.Windows.Storage.Streams.IDataReader, value: win32more.Windows.Storage.Streams.ByteOrder) -> Void: ...
    @winrt_mixinmethod
    def get_InputStreamOptions(self: win32more.Windows.Storage.Streams.IDataReader) -> win32more.Windows.Storage.Streams.InputStreamOptions: ...
    @winrt_mixinmethod
    def put_InputStreamOptions(self: win32more.Windows.Storage.Streams.IDataReader, value: win32more.Windows.Storage.Streams.InputStreamOptions) -> Void: ...
    @winrt_mixinmethod
    def ReadByte(self: win32more.Windows.Storage.Streams.IDataReader) -> Byte: ...
    @winrt_mixinmethod
    def ReadBytes(self: win32more.Windows.Storage.Streams.IDataReader, value: FillArray[Byte]) -> Void: ...
    @winrt_mixinmethod
    def ReadBuffer(self: win32more.Windows.Storage.Streams.IDataReader, length: UInt32) -> win32more.Windows.Storage.Streams.IBuffer: ...
    @winrt_mixinmethod
    def ReadBoolean(self: win32more.Windows.Storage.Streams.IDataReader) -> Boolean: ...
    @winrt_mixinmethod
    def ReadGuid(self: win32more.Windows.Storage.Streams.IDataReader) -> Guid: ...
    @winrt_mixinmethod
    def ReadInt16(self: win32more.Windows.Storage.Streams.IDataReader) -> Int16: ...
    @winrt_mixinmethod
    def ReadInt32(self: win32more.Windows.Storage.Streams.IDataReader) -> Int32: ...
    @winrt_mixinmethod
    def ReadInt64(self: win32more.Windows.Storage.Streams.IDataReader) -> Int64: ...
    @winrt_mixinmethod
    def ReadUInt16(self: win32more.Windows.Storage.Streams.IDataReader) -> UInt16: ...
    @winrt_mixinmethod
    def ReadUInt32(self: win32more.Windows.Storage.Streams.IDataReader) -> UInt32: ...
    @winrt_mixinmethod
    def ReadUInt64(self: win32more.Windows.Storage.Streams.IDataReader) -> UInt64: ...
    @winrt_mixinmethod
    def ReadSingle(self: win32more.Windows.Storage.Streams.IDataReader) -> Single: ...
    @winrt_mixinmethod
    def ReadDouble(self: win32more.Windows.Storage.Streams.IDataReader) -> Double: ...
    @winrt_mixinmethod
    def ReadString(self: win32more.Windows.Storage.Streams.IDataReader, codeUnitCount: UInt32) -> WinRT_String: ...
    @winrt_mixinmethod
    def ReadDateTime(self: win32more.Windows.Storage.Streams.IDataReader) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_mixinmethod
    def ReadTimeSpan(self: win32more.Windows.Storage.Streams.IDataReader) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_mixinmethod
    def LoadAsync(self: win32more.Windows.Storage.Streams.IDataReader, count: UInt32) -> win32more.Windows.Storage.Streams.DataReaderLoadOperation: ...
    @winrt_mixinmethod
    def DetachBuffer(self: win32more.Windows.Storage.Streams.IDataReader) -> win32more.Windows.Storage.Streams.IBuffer: ...
    @winrt_mixinmethod
    def DetachStream(self: win32more.Windows.Storage.Streams.IDataReader) -> win32more.Windows.Storage.Streams.IInputStream: ...
    @winrt_mixinmethod
    def Close(self: win32more.Windows.Foundation.IClosable) -> Void: ...
    @winrt_classmethod
    def FromBuffer(cls: win32more.Windows.Storage.Streams.IDataReaderStatics, buffer: win32more.Windows.Storage.Streams.IBuffer) -> win32more.Windows.Storage.Streams.DataReader: ...
    ByteOrder = property(get_ByteOrder, put_ByteOrder)
    InputStreamOptions = property(get_InputStreamOptions, put_InputStreamOptions)
    UnconsumedBufferLength = property(get_UnconsumedBufferLength, None)
    UnicodeEncoding = property(get_UnicodeEncoding, put_UnicodeEncoding)
class DataReaderLoadOperation(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[AwaitableProtocol]
    default_interface: win32more.Windows.Foundation.IAsyncOperation[UInt32]
    _classid_ = 'Windows.Storage.Streams.DataReaderLoadOperation'
    @winrt_mixinmethod
    def put_Completed(self: win32more.Windows.Foundation.IAsyncOperation[UInt32], handler: win32more.Windows.Foundation.AsyncOperationCompletedHandler[UInt32]) -> Void: ...
    @winrt_mixinmethod
    def get_Completed(self: win32more.Windows.Foundation.IAsyncOperation[UInt32]) -> win32more.Windows.Foundation.AsyncOperationCompletedHandler[UInt32]: ...
    @winrt_mixinmethod
    def GetResults(self: win32more.Windows.Foundation.IAsyncOperation[UInt32]) -> UInt32: ...
    @winrt_mixinmethod
    def get_Id(self: win32more.Windows.Foundation.IAsyncInfo) -> UInt32: ...
    @winrt_mixinmethod
    def get_Status(self: win32more.Windows.Foundation.IAsyncInfo) -> win32more.Windows.Foundation.AsyncStatus: ...
    @winrt_mixinmethod
    def get_ErrorCode(self: win32more.Windows.Foundation.IAsyncInfo) -> win32more.Windows.Foundation.HResult: ...
    @winrt_mixinmethod
    def Cancel(self: win32more.Windows.Foundation.IAsyncInfo) -> Void: ...
    @winrt_mixinmethod
    def Close(self: win32more.Windows.Foundation.IAsyncInfo) -> Void: ...
    Completed = property(get_Completed, put_Completed)
    ErrorCode = property(get_ErrorCode, None)
    Id = property(get_Id, None)
    Status = property(get_Status, None)
class DataWriter(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[ContextManagerProtocol]
    default_interface: win32more.Windows.Storage.Streams.IDataWriter
    _classid_ = 'Windows.Storage.Streams.DataWriter'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.Storage.Streams.DataWriter.CreateInstance(*args))
        elif len(args) == 1:
            super().__init__(move=win32more.Windows.Storage.Streams.DataWriter.CreateDataWriter(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.Storage.Streams.DataWriter: ...
    @winrt_factorymethod
    def CreateDataWriter(cls: win32more.Windows.Storage.Streams.IDataWriterFactory, outputStream: win32more.Windows.Storage.Streams.IOutputStream) -> win32more.Windows.Storage.Streams.DataWriter: ...
    @winrt_mixinmethod
    def get_UnstoredBufferLength(self: win32more.Windows.Storage.Streams.IDataWriter) -> UInt32: ...
    @winrt_mixinmethod
    def get_UnicodeEncoding(self: win32more.Windows.Storage.Streams.IDataWriter) -> win32more.Windows.Storage.Streams.UnicodeEncoding: ...
    @winrt_mixinmethod
    def put_UnicodeEncoding(self: win32more.Windows.Storage.Streams.IDataWriter, value: win32more.Windows.Storage.Streams.UnicodeEncoding) -> Void: ...
    @winrt_mixinmethod
    def get_ByteOrder(self: win32more.Windows.Storage.Streams.IDataWriter) -> win32more.Windows.Storage.Streams.ByteOrder: ...
    @winrt_mixinmethod
    def put_ByteOrder(self: win32more.Windows.Storage.Streams.IDataWriter, value: win32more.Windows.Storage.Streams.ByteOrder) -> Void: ...
    @winrt_mixinmethod
    def WriteByte(self: win32more.Windows.Storage.Streams.IDataWriter, value: Byte) -> Void: ...
    @winrt_mixinmethod
    def WriteBytes(self: win32more.Windows.Storage.Streams.IDataWriter, value: PassArray[Byte]) -> Void: ...
    @winrt_mixinmethod
    def WriteBuffer(self: win32more.Windows.Storage.Streams.IDataWriter, buffer: win32more.Windows.Storage.Streams.IBuffer) -> Void: ...
    @winrt_mixinmethod
    def WriteBufferRange(self: win32more.Windows.Storage.Streams.IDataWriter, buffer: win32more.Windows.Storage.Streams.IBuffer, start: UInt32, count: UInt32) -> Void: ...
    @winrt_mixinmethod
    def WriteBoolean(self: win32more.Windows.Storage.Streams.IDataWriter, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def WriteGuid(self: win32more.Windows.Storage.Streams.IDataWriter, value: Guid) -> Void: ...
    @winrt_mixinmethod
    def WriteInt16(self: win32more.Windows.Storage.Streams.IDataWriter, value: Int16) -> Void: ...
    @winrt_mixinmethod
    def WriteInt32(self: win32more.Windows.Storage.Streams.IDataWriter, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def WriteInt64(self: win32more.Windows.Storage.Streams.IDataWriter, value: Int64) -> Void: ...
    @winrt_mixinmethod
    def WriteUInt16(self: win32more.Windows.Storage.Streams.IDataWriter, value: UInt16) -> Void: ...
    @winrt_mixinmethod
    def WriteUInt32(self: win32more.Windows.Storage.Streams.IDataWriter, value: UInt32) -> Void: ...
    @winrt_mixinmethod
    def WriteUInt64(self: win32more.Windows.Storage.Streams.IDataWriter, value: UInt64) -> Void: ...
    @winrt_mixinmethod
    def WriteSingle(self: win32more.Windows.Storage.Streams.IDataWriter, value: Single) -> Void: ...
    @winrt_mixinmethod
    def WriteDouble(self: win32more.Windows.Storage.Streams.IDataWriter, value: Double) -> Void: ...
    @winrt_mixinmethod
    def WriteDateTime(self: win32more.Windows.Storage.Streams.IDataWriter, value: win32more.Windows.Foundation.DateTime) -> Void: ...
    @winrt_mixinmethod
    def WriteTimeSpan(self: win32more.Windows.Storage.Streams.IDataWriter, value: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    @winrt_mixinmethod
    def WriteString(self: win32more.Windows.Storage.Streams.IDataWriter, value: WinRT_String) -> UInt32: ...
    @winrt_mixinmethod
    def MeasureString(self: win32more.Windows.Storage.Streams.IDataWriter, value: WinRT_String) -> UInt32: ...
    @winrt_mixinmethod
    def StoreAsync(self: win32more.Windows.Storage.Streams.IDataWriter) -> win32more.Windows.Storage.Streams.DataWriterStoreOperation: ...
    @winrt_mixinmethod
    def FlushAsync(self: win32more.Windows.Storage.Streams.IDataWriter) -> win32more.Windows.Foundation.IAsyncOperation[Boolean]: ...
    @winrt_mixinmethod
    def DetachBuffer(self: win32more.Windows.Storage.Streams.IDataWriter) -> win32more.Windows.Storage.Streams.IBuffer: ...
    @winrt_mixinmethod
    def DetachStream(self: win32more.Windows.Storage.Streams.IDataWriter) -> win32more.Windows.Storage.Streams.IOutputStream: ...
    @winrt_mixinmethod
    def Close(self: win32more.Windows.Foundation.IClosable) -> Void: ...
    ByteOrder = property(get_ByteOrder, put_ByteOrder)
    UnicodeEncoding = property(get_UnicodeEncoding, put_UnicodeEncoding)
    UnstoredBufferLength = property(get_UnstoredBufferLength, None)
class DataWriterStoreOperation(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[AwaitableProtocol]
    default_interface: win32more.Windows.Foundation.IAsyncOperation[UInt32]
    _classid_ = 'Windows.Storage.Streams.DataWriterStoreOperation'
    @winrt_mixinmethod
    def put_Completed(self: win32more.Windows.Foundation.IAsyncOperation[UInt32], handler: win32more.Windows.Foundation.AsyncOperationCompletedHandler[UInt32]) -> Void: ...
    @winrt_mixinmethod
    def get_Completed(self: win32more.Windows.Foundation.IAsyncOperation[UInt32]) -> win32more.Windows.Foundation.AsyncOperationCompletedHandler[UInt32]: ...
    @winrt_mixinmethod
    def GetResults(self: win32more.Windows.Foundation.IAsyncOperation[UInt32]) -> UInt32: ...
    @winrt_mixinmethod
    def get_Id(self: win32more.Windows.Foundation.IAsyncInfo) -> UInt32: ...
    @winrt_mixinmethod
    def get_Status(self: win32more.Windows.Foundation.IAsyncInfo) -> win32more.Windows.Foundation.AsyncStatus: ...
    @winrt_mixinmethod
    def get_ErrorCode(self: win32more.Windows.Foundation.IAsyncInfo) -> win32more.Windows.Foundation.HResult: ...
    @winrt_mixinmethod
    def Cancel(self: win32more.Windows.Foundation.IAsyncInfo) -> Void: ...
    @winrt_mixinmethod
    def Close(self: win32more.Windows.Foundation.IAsyncInfo) -> Void: ...
    Completed = property(get_Completed, put_Completed)
    ErrorCode = property(get_ErrorCode, None)
    Id = property(get_Id, None)
    Status = property(get_Status, None)
class FileInputStream(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[ContextManagerProtocol]
    default_interface: win32more.Windows.Storage.Streams.IInputStream
    _classid_ = 'Windows.Storage.Streams.FileInputStream'
    @winrt_mixinmethod
    def ReadAsync(self: win32more.Windows.Storage.Streams.IInputStream, buffer: win32more.Windows.Storage.Streams.IBuffer, count: UInt32, options: win32more.Windows.Storage.Streams.InputStreamOptions) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Windows.Storage.Streams.IBuffer, UInt32]: ...
    @winrt_mixinmethod
    def Close(self: win32more.Windows.Foundation.IClosable) -> Void: ...
class FileOpenDisposition(Enum, Int32):
    OpenExisting = 0
    OpenAlways = 1
    CreateNew = 2
    CreateAlways = 3
    TruncateExisting = 4
class FileOutputStream(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[ContextManagerProtocol]
    default_interface: win32more.Windows.Storage.Streams.IOutputStream
    _classid_ = 'Windows.Storage.Streams.FileOutputStream'
    @winrt_mixinmethod
    def WriteAsync(self: win32more.Windows.Storage.Streams.IOutputStream, buffer: win32more.Windows.Storage.Streams.IBuffer) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[UInt32, UInt32]: ...
    @winrt_mixinmethod
    def FlushAsync(self: win32more.Windows.Storage.Streams.IOutputStream) -> win32more.Windows.Foundation.IAsyncOperation[Boolean]: ...
    @winrt_mixinmethod
    def Close(self: win32more.Windows.Foundation.IClosable) -> Void: ...
class FileRandomAccessStream(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[ContextManagerProtocol]
    default_interface: win32more.Windows.Storage.Streams.IRandomAccessStream
    _classid_ = 'Windows.Storage.Streams.FileRandomAccessStream'
    @winrt_mixinmethod
    def get_Size(self: win32more.Windows.Storage.Streams.IRandomAccessStream) -> UInt64: ...
    @winrt_mixinmethod
    def put_Size(self: win32more.Windows.Storage.Streams.IRandomAccessStream, value: UInt64) -> Void: ...
    @winrt_mixinmethod
    def GetInputStreamAt(self: win32more.Windows.Storage.Streams.IRandomAccessStream, position: UInt64) -> win32more.Windows.Storage.Streams.IInputStream: ...
    @winrt_mixinmethod
    def GetOutputStreamAt(self: win32more.Windows.Storage.Streams.IRandomAccessStream, position: UInt64) -> win32more.Windows.Storage.Streams.IOutputStream: ...
    @winrt_mixinmethod
    def get_Position(self: win32more.Windows.Storage.Streams.IRandomAccessStream) -> UInt64: ...
    @winrt_mixinmethod
    def Seek(self: win32more.Windows.Storage.Streams.IRandomAccessStream, position: UInt64) -> Void: ...
    @winrt_mixinmethod
    def CloneStream(self: win32more.Windows.Storage.Streams.IRandomAccessStream) -> win32more.Windows.Storage.Streams.IRandomAccessStream: ...
    @winrt_mixinmethod
    def get_CanRead(self: win32more.Windows.Storage.Streams.IRandomAccessStream) -> Boolean: ...
    @winrt_mixinmethod
    def get_CanWrite(self: win32more.Windows.Storage.Streams.IRandomAccessStream) -> Boolean: ...
    @winrt_mixinmethod
    def Close(self: win32more.Windows.Foundation.IClosable) -> Void: ...
    @winrt_mixinmethod
    def ReadAsync(self: win32more.Windows.Storage.Streams.IInputStream, buffer: win32more.Windows.Storage.Streams.IBuffer, count: UInt32, options: win32more.Windows.Storage.Streams.InputStreamOptions) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Windows.Storage.Streams.IBuffer, UInt32]: ...
    @winrt_mixinmethod
    def WriteAsync(self: win32more.Windows.Storage.Streams.IOutputStream, buffer: win32more.Windows.Storage.Streams.IBuffer) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[UInt32, UInt32]: ...
    @winrt_mixinmethod
    def FlushAsync(self: win32more.Windows.Storage.Streams.IOutputStream) -> win32more.Windows.Foundation.IAsyncOperation[Boolean]: ...
    @winrt_classmethod
    def OpenAsync(cls: win32more.Windows.Storage.Streams.IFileRandomAccessStreamStatics, filePath: WinRT_String, accessMode: win32more.Windows.Storage.FileAccessMode) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.Streams.IRandomAccessStream]: ...
    @winrt_classmethod
    def OpenWithOptionsAsync(cls: win32more.Windows.Storage.Streams.IFileRandomAccessStreamStatics, filePath: WinRT_String, accessMode: win32more.Windows.Storage.FileAccessMode, sharingOptions: win32more.Windows.Storage.StorageOpenOptions, openDisposition: win32more.Windows.Storage.Streams.FileOpenDisposition) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.Streams.IRandomAccessStream]: ...
    @winrt_classmethod
    def OpenTransactedWriteAsync(cls: win32more.Windows.Storage.Streams.IFileRandomAccessStreamStatics, filePath: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.StorageStreamTransaction]: ...
    @winrt_classmethod
    def OpenTransactedWriteWithOptionsAsync(cls: win32more.Windows.Storage.Streams.IFileRandomAccessStreamStatics, filePath: WinRT_String, openOptions: win32more.Windows.Storage.StorageOpenOptions, openDisposition: win32more.Windows.Storage.Streams.FileOpenDisposition) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.StorageStreamTransaction]: ...
    @winrt_classmethod
    def OpenForUserAsync(cls: win32more.Windows.Storage.Streams.IFileRandomAccessStreamStatics, user: win32more.Windows.System.User, filePath: WinRT_String, accessMode: win32more.Windows.Storage.FileAccessMode) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.Streams.IRandomAccessStream]: ...
    @winrt_classmethod
    def OpenForUserWithOptionsAsync(cls: win32more.Windows.Storage.Streams.IFileRandomAccessStreamStatics, user: win32more.Windows.System.User, filePath: WinRT_String, accessMode: win32more.Windows.Storage.FileAccessMode, sharingOptions: win32more.Windows.Storage.StorageOpenOptions, openDisposition: win32more.Windows.Storage.Streams.FileOpenDisposition) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.Streams.IRandomAccessStream]: ...
    @winrt_classmethod
    def OpenTransactedWriteForUserAsync(cls: win32more.Windows.Storage.Streams.IFileRandomAccessStreamStatics, user: win32more.Windows.System.User, filePath: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.StorageStreamTransaction]: ...
    @winrt_classmethod
    def OpenTransactedWriteForUserWithOptionsAsync(cls: win32more.Windows.Storage.Streams.IFileRandomAccessStreamStatics, user: win32more.Windows.System.User, filePath: WinRT_String, openOptions: win32more.Windows.Storage.StorageOpenOptions, openDisposition: win32more.Windows.Storage.Streams.FileOpenDisposition) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.StorageStreamTransaction]: ...
    CanRead = property(get_CanRead, None)
    CanWrite = property(get_CanWrite, None)
    Position = property(get_Position, None)
    Size = property(get_Size, put_Size)
class IBuffer(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Storage.Streams.IBuffer'
    _iid_ = Guid('{905a0fe0-bc53-11df-8c49-001e4fc686da}')
    @winrt_commethod(6)
    def get_Capacity(self) -> UInt32: ...
    @winrt_commethod(7)
    def get_Length(self) -> UInt32: ...
    @winrt_commethod(8)
    def put_Length(self, value: UInt32) -> Void: ...
    Capacity = property(get_Capacity, None)
    Length = property(get_Length, put_Length)
class IBufferFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Storage.Streams.IBufferFactory'
    _iid_ = Guid('{71af914d-c10f-484b-bc50-14bc623b3a27}')
    @winrt_commethod(6)
    def Create(self, capacity: UInt32) -> win32more.Windows.Storage.Streams.Buffer: ...
class IBufferStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Storage.Streams.IBufferStatics'
    _iid_ = Guid('{e901e65b-d716-475a-a90a-af7229b1e741}')
    @winrt_commethod(6)
    def CreateCopyFromMemoryBuffer(self, input: win32more.Windows.Foundation.IMemoryBuffer) -> win32more.Windows.Storage.Streams.Buffer: ...
    @winrt_commethod(7)
    def CreateMemoryBufferOverIBuffer(self, input: win32more.Windows.Storage.Streams.IBuffer) -> win32more.Windows.Foundation.MemoryBuffer: ...
class IContentTypeProvider(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Storage.Streams.IContentTypeProvider'
    _iid_ = Guid('{97d098a5-3b99-4de9-88a5-e11d2f50c795}')
    @winrt_commethod(6)
    def get_ContentType(self) -> WinRT_String: ...
    ContentType = property(get_ContentType, None)
class IDataReader(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Storage.Streams.IDataReader'
    _iid_ = Guid('{e2b50029-b4c1-4314-a4b8-fb813a2f275e}')
    @winrt_commethod(6)
    def get_UnconsumedBufferLength(self) -> UInt32: ...
    @winrt_commethod(7)
    def get_UnicodeEncoding(self) -> win32more.Windows.Storage.Streams.UnicodeEncoding: ...
    @winrt_commethod(8)
    def put_UnicodeEncoding(self, value: win32more.Windows.Storage.Streams.UnicodeEncoding) -> Void: ...
    @winrt_commethod(9)
    def get_ByteOrder(self) -> win32more.Windows.Storage.Streams.ByteOrder: ...
    @winrt_commethod(10)
    def put_ByteOrder(self, value: win32more.Windows.Storage.Streams.ByteOrder) -> Void: ...
    @winrt_commethod(11)
    def get_InputStreamOptions(self) -> win32more.Windows.Storage.Streams.InputStreamOptions: ...
    @winrt_commethod(12)
    def put_InputStreamOptions(self, value: win32more.Windows.Storage.Streams.InputStreamOptions) -> Void: ...
    @winrt_commethod(13)
    def ReadByte(self) -> Byte: ...
    @winrt_commethod(14)
    def ReadBytes(self, value: FillArray[Byte]) -> Void: ...
    @winrt_commethod(15)
    def ReadBuffer(self, length: UInt32) -> win32more.Windows.Storage.Streams.IBuffer: ...
    @winrt_commethod(16)
    def ReadBoolean(self) -> Boolean: ...
    @winrt_commethod(17)
    def ReadGuid(self) -> Guid: ...
    @winrt_commethod(18)
    def ReadInt16(self) -> Int16: ...
    @winrt_commethod(19)
    def ReadInt32(self) -> Int32: ...
    @winrt_commethod(20)
    def ReadInt64(self) -> Int64: ...
    @winrt_commethod(21)
    def ReadUInt16(self) -> UInt16: ...
    @winrt_commethod(22)
    def ReadUInt32(self) -> UInt32: ...
    @winrt_commethod(23)
    def ReadUInt64(self) -> UInt64: ...
    @winrt_commethod(24)
    def ReadSingle(self) -> Single: ...
    @winrt_commethod(25)
    def ReadDouble(self) -> Double: ...
    @winrt_commethod(26)
    def ReadString(self, codeUnitCount: UInt32) -> WinRT_String: ...
    @winrt_commethod(27)
    def ReadDateTime(self) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_commethod(28)
    def ReadTimeSpan(self) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_commethod(29)
    def LoadAsync(self, count: UInt32) -> win32more.Windows.Storage.Streams.DataReaderLoadOperation: ...
    @winrt_commethod(30)
    def DetachBuffer(self) -> win32more.Windows.Storage.Streams.IBuffer: ...
    @winrt_commethod(31)
    def DetachStream(self) -> win32more.Windows.Storage.Streams.IInputStream: ...
    ByteOrder = property(get_ByteOrder, put_ByteOrder)
    InputStreamOptions = property(get_InputStreamOptions, put_InputStreamOptions)
    UnconsumedBufferLength = property(get_UnconsumedBufferLength, None)
    UnicodeEncoding = property(get_UnicodeEncoding, put_UnicodeEncoding)
class IDataReaderFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Storage.Streams.IDataReaderFactory'
    _iid_ = Guid('{d7527847-57da-4e15-914c-06806699a098}')
    @winrt_commethod(6)
    def CreateDataReader(self, inputStream: win32more.Windows.Storage.Streams.IInputStream) -> win32more.Windows.Storage.Streams.DataReader: ...
class IDataReaderStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Storage.Streams.IDataReaderStatics'
    _iid_ = Guid('{11fcbfc8-f93a-471b-b121-f379e349313c}')
    @winrt_commethod(6)
    def FromBuffer(self, buffer: win32more.Windows.Storage.Streams.IBuffer) -> win32more.Windows.Storage.Streams.DataReader: ...
class IDataWriter(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Storage.Streams.IDataWriter'
    _iid_ = Guid('{64b89265-d341-4922-b38a-dd4af8808c4e}')
    @winrt_commethod(6)
    def get_UnstoredBufferLength(self) -> UInt32: ...
    @winrt_commethod(7)
    def get_UnicodeEncoding(self) -> win32more.Windows.Storage.Streams.UnicodeEncoding: ...
    @winrt_commethod(8)
    def put_UnicodeEncoding(self, value: win32more.Windows.Storage.Streams.UnicodeEncoding) -> Void: ...
    @winrt_commethod(9)
    def get_ByteOrder(self) -> win32more.Windows.Storage.Streams.ByteOrder: ...
    @winrt_commethod(10)
    def put_ByteOrder(self, value: win32more.Windows.Storage.Streams.ByteOrder) -> Void: ...
    @winrt_commethod(11)
    def WriteByte(self, value: Byte) -> Void: ...
    @winrt_commethod(12)
    def WriteBytes(self, value: PassArray[Byte]) -> Void: ...
    @winrt_commethod(13)
    def WriteBuffer(self, buffer: win32more.Windows.Storage.Streams.IBuffer) -> Void: ...
    @winrt_commethod(14)
    def WriteBufferRange(self, buffer: win32more.Windows.Storage.Streams.IBuffer, start: UInt32, count: UInt32) -> Void: ...
    @winrt_commethod(15)
    def WriteBoolean(self, value: Boolean) -> Void: ...
    @winrt_commethod(16)
    def WriteGuid(self, value: Guid) -> Void: ...
    @winrt_commethod(17)
    def WriteInt16(self, value: Int16) -> Void: ...
    @winrt_commethod(18)
    def WriteInt32(self, value: Int32) -> Void: ...
    @winrt_commethod(19)
    def WriteInt64(self, value: Int64) -> Void: ...
    @winrt_commethod(20)
    def WriteUInt16(self, value: UInt16) -> Void: ...
    @winrt_commethod(21)
    def WriteUInt32(self, value: UInt32) -> Void: ...
    @winrt_commethod(22)
    def WriteUInt64(self, value: UInt64) -> Void: ...
    @winrt_commethod(23)
    def WriteSingle(self, value: Single) -> Void: ...
    @winrt_commethod(24)
    def WriteDouble(self, value: Double) -> Void: ...
    @winrt_commethod(25)
    def WriteDateTime(self, value: win32more.Windows.Foundation.DateTime) -> Void: ...
    @winrt_commethod(26)
    def WriteTimeSpan(self, value: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    @winrt_commethod(27)
    def WriteString(self, value: WinRT_String) -> UInt32: ...
    @winrt_commethod(28)
    def MeasureString(self, value: WinRT_String) -> UInt32: ...
    @winrt_commethod(29)
    def StoreAsync(self) -> win32more.Windows.Storage.Streams.DataWriterStoreOperation: ...
    @winrt_commethod(30)
    def FlushAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[Boolean]: ...
    @winrt_commethod(31)
    def DetachBuffer(self) -> win32more.Windows.Storage.Streams.IBuffer: ...
    @winrt_commethod(32)
    def DetachStream(self) -> win32more.Windows.Storage.Streams.IOutputStream: ...
    ByteOrder = property(get_ByteOrder, put_ByteOrder)
    UnicodeEncoding = property(get_UnicodeEncoding, put_UnicodeEncoding)
    UnstoredBufferLength = property(get_UnstoredBufferLength, None)
class IDataWriterFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Storage.Streams.IDataWriterFactory'
    _iid_ = Guid('{338c67c2-8b84-4c2b-9c50-7b8767847a1f}')
    @winrt_commethod(6)
    def CreateDataWriter(self, outputStream: win32more.Windows.Storage.Streams.IOutputStream) -> win32more.Windows.Storage.Streams.DataWriter: ...
class IFileRandomAccessStreamStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Storage.Streams.IFileRandomAccessStreamStatics'
    _iid_ = Guid('{73550107-3b57-4b5d-8345-554d2fc621f0}')
    @winrt_commethod(6)
    def OpenAsync(self, filePath: WinRT_String, accessMode: win32more.Windows.Storage.FileAccessMode) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.Streams.IRandomAccessStream]: ...
    @winrt_commethod(7)
    def OpenWithOptionsAsync(self, filePath: WinRT_String, accessMode: win32more.Windows.Storage.FileAccessMode, sharingOptions: win32more.Windows.Storage.StorageOpenOptions, openDisposition: win32more.Windows.Storage.Streams.FileOpenDisposition) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.Streams.IRandomAccessStream]: ...
    @winrt_commethod(8)
    def OpenTransactedWriteAsync(self, filePath: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.StorageStreamTransaction]: ...
    @winrt_commethod(9)
    def OpenTransactedWriteWithOptionsAsync(self, filePath: WinRT_String, openOptions: win32more.Windows.Storage.StorageOpenOptions, openDisposition: win32more.Windows.Storage.Streams.FileOpenDisposition) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.StorageStreamTransaction]: ...
    @winrt_commethod(10)
    def OpenForUserAsync(self, user: win32more.Windows.System.User, filePath: WinRT_String, accessMode: win32more.Windows.Storage.FileAccessMode) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.Streams.IRandomAccessStream]: ...
    @winrt_commethod(11)
    def OpenForUserWithOptionsAsync(self, user: win32more.Windows.System.User, filePath: WinRT_String, accessMode: win32more.Windows.Storage.FileAccessMode, sharingOptions: win32more.Windows.Storage.StorageOpenOptions, openDisposition: win32more.Windows.Storage.Streams.FileOpenDisposition) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.Streams.IRandomAccessStream]: ...
    @winrt_commethod(12)
    def OpenTransactedWriteForUserAsync(self, user: win32more.Windows.System.User, filePath: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.StorageStreamTransaction]: ...
    @winrt_commethod(13)
    def OpenTransactedWriteForUserWithOptionsAsync(self, user: win32more.Windows.System.User, filePath: WinRT_String, openOptions: win32more.Windows.Storage.StorageOpenOptions, openDisposition: win32more.Windows.Storage.Streams.FileOpenDisposition) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.StorageStreamTransaction]: ...
class IInputStream(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[ContextManagerProtocol]
    _classid_ = 'Windows.Storage.Streams.IInputStream'
    _iid_ = Guid('{905a0fe2-bc53-11df-8c49-001e4fc686da}')
    @winrt_commethod(6)
    def ReadAsync(self, buffer: win32more.Windows.Storage.Streams.IBuffer, count: UInt32, options: win32more.Windows.Storage.Streams.InputStreamOptions) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Windows.Storage.Streams.IBuffer, UInt32]: ...
class IInputStreamReference(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Storage.Streams.IInputStreamReference'
    _iid_ = Guid('{43929d18-5ec9-4b5a-919c-4205b0c804b6}')
    @winrt_commethod(6)
    def OpenSequentialReadAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.Streams.IInputStream]: ...
class IOutputStream(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[ContextManagerProtocol]
    _classid_ = 'Windows.Storage.Streams.IOutputStream'
    _iid_ = Guid('{905a0fe6-bc53-11df-8c49-001e4fc686da}')
    @winrt_commethod(6)
    def WriteAsync(self, buffer: win32more.Windows.Storage.Streams.IBuffer) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[UInt32, UInt32]: ...
    @winrt_commethod(7)
    def FlushAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[Boolean]: ...
class IPropertySetSerializer(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Storage.Streams.IPropertySetSerializer'
    _iid_ = Guid('{6e8ebf1c-ef3d-4376-b20e-5be638aeac77}')
    @winrt_commethod(6)
    def Serialize(self, propertySet: win32more.Windows.Foundation.Collections.IPropertySet) -> win32more.Windows.Storage.Streams.IBuffer: ...
    @winrt_commethod(7)
    def Deserialize(self, propertySet: win32more.Windows.Foundation.Collections.IPropertySet, buffer: win32more.Windows.Storage.Streams.IBuffer) -> Void: ...
class IRandomAccessStream(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[ContextManagerProtocol]
    _classid_ = 'Windows.Storage.Streams.IRandomAccessStream'
    _iid_ = Guid('{905a0fe1-bc53-11df-8c49-001e4fc686da}')
    @winrt_commethod(6)
    def get_Size(self) -> UInt64: ...
    @winrt_commethod(7)
    def put_Size(self, value: UInt64) -> Void: ...
    @winrt_commethod(8)
    def GetInputStreamAt(self, position: UInt64) -> win32more.Windows.Storage.Streams.IInputStream: ...
    @winrt_commethod(9)
    def GetOutputStreamAt(self, position: UInt64) -> win32more.Windows.Storage.Streams.IOutputStream: ...
    @winrt_commethod(10)
    def get_Position(self) -> UInt64: ...
    @winrt_commethod(11)
    def Seek(self, position: UInt64) -> Void: ...
    @winrt_commethod(12)
    def CloneStream(self) -> win32more.Windows.Storage.Streams.IRandomAccessStream: ...
    @winrt_commethod(13)
    def get_CanRead(self) -> Boolean: ...
    @winrt_commethod(14)
    def get_CanWrite(self) -> Boolean: ...
    CanRead = property(get_CanRead, None)
    CanWrite = property(get_CanWrite, None)
    Position = property(get_Position, None)
    Size = property(get_Size, put_Size)
class IRandomAccessStreamReference(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Storage.Streams.IRandomAccessStreamReference'
    _iid_ = Guid('{33ee3134-1dd6-4e3a-8067-d1c162e8642b}')
    @winrt_commethod(6)
    def OpenReadAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.Streams.IRandomAccessStreamWithContentType]: ...
class IRandomAccessStreamReferenceStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Storage.Streams.IRandomAccessStreamReferenceStatics'
    _iid_ = Guid('{857309dc-3fbf-4e7d-986f-ef3b1a07a964}')
    @winrt_commethod(6)
    def CreateFromFile(self, file: win32more.Windows.Storage.IStorageFile) -> win32more.Windows.Storage.Streams.RandomAccessStreamReference: ...
    @winrt_commethod(7)
    def CreateFromUri(self, uri: win32more.Windows.Foundation.Uri) -> win32more.Windows.Storage.Streams.RandomAccessStreamReference: ...
    @winrt_commethod(8)
    def CreateFromStream(self, stream: win32more.Windows.Storage.Streams.IRandomAccessStream) -> win32more.Windows.Storage.Streams.RandomAccessStreamReference: ...
class IRandomAccessStreamStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Storage.Streams.IRandomAccessStreamStatics'
    _iid_ = Guid('{524cedcf-6e29-4ce5-9573-6b753db66c3a}')
    @winrt_commethod(6)
    def CopyAsync(self, source: win32more.Windows.Storage.Streams.IInputStream, destination: win32more.Windows.Storage.Streams.IOutputStream) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[UInt64, UInt64]: ...
    @winrt_commethod(7)
    def CopySizeAsync(self, source: win32more.Windows.Storage.Streams.IInputStream, destination: win32more.Windows.Storage.Streams.IOutputStream, bytesToCopy: UInt64) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[UInt64, UInt64]: ...
    @winrt_commethod(8)
    def CopyAndCloseAsync(self, source: win32more.Windows.Storage.Streams.IInputStream, destination: win32more.Windows.Storage.Streams.IOutputStream) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[UInt64, UInt64]: ...
class IRandomAccessStreamWithContentType(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[ContextManagerProtocol]
    _classid_ = 'Windows.Storage.Streams.IRandomAccessStreamWithContentType'
    _iid_ = Guid('{cc254827-4b3d-438f-9232-10c76bc7e038}')
class InMemoryRandomAccessStream(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[ContextManagerProtocol]
    default_interface: win32more.Windows.Storage.Streams.IRandomAccessStream
    _classid_ = 'Windows.Storage.Streams.InMemoryRandomAccessStream'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.Storage.Streams.InMemoryRandomAccessStream.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.Storage.Streams.InMemoryRandomAccessStream: ...
    @winrt_mixinmethod
    def get_Size(self: win32more.Windows.Storage.Streams.IRandomAccessStream) -> UInt64: ...
    @winrt_mixinmethod
    def put_Size(self: win32more.Windows.Storage.Streams.IRandomAccessStream, value: UInt64) -> Void: ...
    @winrt_mixinmethod
    def GetInputStreamAt(self: win32more.Windows.Storage.Streams.IRandomAccessStream, position: UInt64) -> win32more.Windows.Storage.Streams.IInputStream: ...
    @winrt_mixinmethod
    def GetOutputStreamAt(self: win32more.Windows.Storage.Streams.IRandomAccessStream, position: UInt64) -> win32more.Windows.Storage.Streams.IOutputStream: ...
    @winrt_mixinmethod
    def get_Position(self: win32more.Windows.Storage.Streams.IRandomAccessStream) -> UInt64: ...
    @winrt_mixinmethod
    def Seek(self: win32more.Windows.Storage.Streams.IRandomAccessStream, position: UInt64) -> Void: ...
    @winrt_mixinmethod
    def CloneStream(self: win32more.Windows.Storage.Streams.IRandomAccessStream) -> win32more.Windows.Storage.Streams.IRandomAccessStream: ...
    @winrt_mixinmethod
    def get_CanRead(self: win32more.Windows.Storage.Streams.IRandomAccessStream) -> Boolean: ...
    @winrt_mixinmethod
    def get_CanWrite(self: win32more.Windows.Storage.Streams.IRandomAccessStream) -> Boolean: ...
    @winrt_mixinmethod
    def Close(self: win32more.Windows.Foundation.IClosable) -> Void: ...
    @winrt_mixinmethod
    def ReadAsync(self: win32more.Windows.Storage.Streams.IInputStream, buffer: win32more.Windows.Storage.Streams.IBuffer, count: UInt32, options: win32more.Windows.Storage.Streams.InputStreamOptions) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Windows.Storage.Streams.IBuffer, UInt32]: ...
    @winrt_mixinmethod
    def WriteAsync(self: win32more.Windows.Storage.Streams.IOutputStream, buffer: win32more.Windows.Storage.Streams.IBuffer) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[UInt32, UInt32]: ...
    @winrt_mixinmethod
    def FlushAsync(self: win32more.Windows.Storage.Streams.IOutputStream) -> win32more.Windows.Foundation.IAsyncOperation[Boolean]: ...
    CanRead = property(get_CanRead, None)
    CanWrite = property(get_CanWrite, None)
    Position = property(get_Position, None)
    Size = property(get_Size, put_Size)
class InputStreamOptions(Enum, UInt32):
    None_ = 0
    Partial = 1
    ReadAhead = 2
class InputStreamOverStream(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[ContextManagerProtocol]
    default_interface: win32more.Windows.Storage.Streams.IInputStream
    _classid_ = 'Windows.Storage.Streams.InputStreamOverStream'
    @winrt_mixinmethod
    def ReadAsync(self: win32more.Windows.Storage.Streams.IInputStream, buffer: win32more.Windows.Storage.Streams.IBuffer, count: UInt32, options: win32more.Windows.Storage.Streams.InputStreamOptions) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Windows.Storage.Streams.IBuffer, UInt32]: ...
    @winrt_mixinmethod
    def Close(self: win32more.Windows.Foundation.IClosable) -> Void: ...
class OutputStreamOverStream(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[ContextManagerProtocol]
    default_interface: win32more.Windows.Storage.Streams.IOutputStream
    _classid_ = 'Windows.Storage.Streams.OutputStreamOverStream'
    @winrt_mixinmethod
    def WriteAsync(self: win32more.Windows.Storage.Streams.IOutputStream, buffer: win32more.Windows.Storage.Streams.IBuffer) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[UInt32, UInt32]: ...
    @winrt_mixinmethod
    def FlushAsync(self: win32more.Windows.Storage.Streams.IOutputStream) -> win32more.Windows.Foundation.IAsyncOperation[Boolean]: ...
    @winrt_mixinmethod
    def Close(self: win32more.Windows.Foundation.IClosable) -> Void: ...
class RandomAccessStream(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Storage.Streams.RandomAccessStream'
    @winrt_classmethod
    def CopyAsync(cls: win32more.Windows.Storage.Streams.IRandomAccessStreamStatics, source: win32more.Windows.Storage.Streams.IInputStream, destination: win32more.Windows.Storage.Streams.IOutputStream) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[UInt64, UInt64]: ...
    @winrt_classmethod
    def CopySizeAsync(cls: win32more.Windows.Storage.Streams.IRandomAccessStreamStatics, source: win32more.Windows.Storage.Streams.IInputStream, destination: win32more.Windows.Storage.Streams.IOutputStream, bytesToCopy: UInt64) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[UInt64, UInt64]: ...
    @winrt_classmethod
    def CopyAndCloseAsync(cls: win32more.Windows.Storage.Streams.IRandomAccessStreamStatics, source: win32more.Windows.Storage.Streams.IInputStream, destination: win32more.Windows.Storage.Streams.IOutputStream) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[UInt64, UInt64]: ...
class RandomAccessStreamOverStream(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[ContextManagerProtocol]
    default_interface: win32more.Windows.Storage.Streams.IRandomAccessStream
    _classid_ = 'Windows.Storage.Streams.RandomAccessStreamOverStream'
    @winrt_mixinmethod
    def get_Size(self: win32more.Windows.Storage.Streams.IRandomAccessStream) -> UInt64: ...
    @winrt_mixinmethod
    def put_Size(self: win32more.Windows.Storage.Streams.IRandomAccessStream, value: UInt64) -> Void: ...
    @winrt_mixinmethod
    def GetInputStreamAt(self: win32more.Windows.Storage.Streams.IRandomAccessStream, position: UInt64) -> win32more.Windows.Storage.Streams.IInputStream: ...
    @winrt_mixinmethod
    def GetOutputStreamAt(self: win32more.Windows.Storage.Streams.IRandomAccessStream, position: UInt64) -> win32more.Windows.Storage.Streams.IOutputStream: ...
    @winrt_mixinmethod
    def get_Position(self: win32more.Windows.Storage.Streams.IRandomAccessStream) -> UInt64: ...
    @winrt_mixinmethod
    def Seek(self: win32more.Windows.Storage.Streams.IRandomAccessStream, position: UInt64) -> Void: ...
    @winrt_mixinmethod
    def CloneStream(self: win32more.Windows.Storage.Streams.IRandomAccessStream) -> win32more.Windows.Storage.Streams.IRandomAccessStream: ...
    @winrt_mixinmethod
    def get_CanRead(self: win32more.Windows.Storage.Streams.IRandomAccessStream) -> Boolean: ...
    @winrt_mixinmethod
    def get_CanWrite(self: win32more.Windows.Storage.Streams.IRandomAccessStream) -> Boolean: ...
    @winrt_mixinmethod
    def Close(self: win32more.Windows.Foundation.IClosable) -> Void: ...
    @winrt_mixinmethod
    def ReadAsync(self: win32more.Windows.Storage.Streams.IInputStream, buffer: win32more.Windows.Storage.Streams.IBuffer, count: UInt32, options: win32more.Windows.Storage.Streams.InputStreamOptions) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Windows.Storage.Streams.IBuffer, UInt32]: ...
    @winrt_mixinmethod
    def WriteAsync(self: win32more.Windows.Storage.Streams.IOutputStream, buffer: win32more.Windows.Storage.Streams.IBuffer) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[UInt32, UInt32]: ...
    @winrt_mixinmethod
    def FlushAsync(self: win32more.Windows.Storage.Streams.IOutputStream) -> win32more.Windows.Foundation.IAsyncOperation[Boolean]: ...
    CanRead = property(get_CanRead, None)
    CanWrite = property(get_CanWrite, None)
    Position = property(get_Position, None)
    Size = property(get_Size, put_Size)
class RandomAccessStreamReference(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Storage.Streams.IRandomAccessStreamReference
    _classid_ = 'Windows.Storage.Streams.RandomAccessStreamReference'
    @winrt_mixinmethod
    def OpenReadAsync(self: win32more.Windows.Storage.Streams.IRandomAccessStreamReference) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.Streams.IRandomAccessStreamWithContentType]: ...
    @winrt_classmethod
    def CreateFromFile(cls: win32more.Windows.Storage.Streams.IRandomAccessStreamReferenceStatics, file: win32more.Windows.Storage.IStorageFile) -> win32more.Windows.Storage.Streams.RandomAccessStreamReference: ...
    @winrt_classmethod
    def CreateFromUri(cls: win32more.Windows.Storage.Streams.IRandomAccessStreamReferenceStatics, uri: win32more.Windows.Foundation.Uri) -> win32more.Windows.Storage.Streams.RandomAccessStreamReference: ...
    @winrt_classmethod
    def CreateFromStream(cls: win32more.Windows.Storage.Streams.IRandomAccessStreamReferenceStatics, stream: win32more.Windows.Storage.Streams.IRandomAccessStream) -> win32more.Windows.Storage.Streams.RandomAccessStreamReference: ...
class UnicodeEncoding(Enum, Int32):
    Utf8 = 0
    Utf16LE = 1
    Utf16BE = 2


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Devices.Properties
import win32more.Windows.Win32.Foundation
DEVPROP_TRUE: win32more.Windows.Win32.Devices.Properties.DEVPROP_BOOLEAN = 255
DEVPROP_FALSE: win32more.Windows.Win32.Devices.Properties.DEVPROP_BOOLEAN = 0
DEVPKEY_DeviceInterface_Autoplay_Silent: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{434dd28f-9e75-450a-9ab9-ff61e618bad0}'), pid=2)
DEVPKEY_NAME: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{b725f130-47ef-101a-a5f1-02608c9eebac}'), pid=10)
DEVPKEY_Device_DeviceDesc: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{a45c254e-df1c-4efd-8020-67d146a850e0}'), pid=2)
DEVPKEY_Device_HardwareIds: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{a45c254e-df1c-4efd-8020-67d146a850e0}'), pid=3)
DEVPKEY_Device_CompatibleIds: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{a45c254e-df1c-4efd-8020-67d146a850e0}'), pid=4)
DEVPKEY_Device_Service: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{a45c254e-df1c-4efd-8020-67d146a850e0}'), pid=6)
DEVPKEY_Device_Class: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{a45c254e-df1c-4efd-8020-67d146a850e0}'), pid=9)
DEVPKEY_Device_ClassGuid: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{a45c254e-df1c-4efd-8020-67d146a850e0}'), pid=10)
DEVPKEY_Device_Driver: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{a45c254e-df1c-4efd-8020-67d146a850e0}'), pid=11)
DEVPKEY_Device_ConfigFlags: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{a45c254e-df1c-4efd-8020-67d146a850e0}'), pid=12)
DEVPKEY_Device_Manufacturer: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{a45c254e-df1c-4efd-8020-67d146a850e0}'), pid=13)
DEVPKEY_Device_FriendlyName: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{a45c254e-df1c-4efd-8020-67d146a850e0}'), pid=14)
DEVPKEY_Device_LocationInfo: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{a45c254e-df1c-4efd-8020-67d146a850e0}'), pid=15)
DEVPKEY_Device_PDOName: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{a45c254e-df1c-4efd-8020-67d146a850e0}'), pid=16)
DEVPKEY_Device_Capabilities: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{a45c254e-df1c-4efd-8020-67d146a850e0}'), pid=17)
DEVPKEY_Device_UINumber: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{a45c254e-df1c-4efd-8020-67d146a850e0}'), pid=18)
DEVPKEY_Device_UpperFilters: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{a45c254e-df1c-4efd-8020-67d146a850e0}'), pid=19)
DEVPKEY_Device_LowerFilters: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{a45c254e-df1c-4efd-8020-67d146a850e0}'), pid=20)
DEVPKEY_Device_BusTypeGuid: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{a45c254e-df1c-4efd-8020-67d146a850e0}'), pid=21)
DEVPKEY_Device_LegacyBusType: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{a45c254e-df1c-4efd-8020-67d146a850e0}'), pid=22)
DEVPKEY_Device_BusNumber: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{a45c254e-df1c-4efd-8020-67d146a850e0}'), pid=23)
DEVPKEY_Device_EnumeratorName: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{a45c254e-df1c-4efd-8020-67d146a850e0}'), pid=24)
DEVPKEY_Device_Security: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{a45c254e-df1c-4efd-8020-67d146a850e0}'), pid=25)
DEVPKEY_Device_SecuritySDS: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{a45c254e-df1c-4efd-8020-67d146a850e0}'), pid=26)
DEVPKEY_Device_DevType: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{a45c254e-df1c-4efd-8020-67d146a850e0}'), pid=27)
DEVPKEY_Device_Exclusive: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{a45c254e-df1c-4efd-8020-67d146a850e0}'), pid=28)
DEVPKEY_Device_Characteristics: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{a45c254e-df1c-4efd-8020-67d146a850e0}'), pid=29)
DEVPKEY_Device_Address: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{a45c254e-df1c-4efd-8020-67d146a850e0}'), pid=30)
DEVPKEY_Device_UINumberDescFormat: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{a45c254e-df1c-4efd-8020-67d146a850e0}'), pid=31)
DEVPKEY_Device_PowerData: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{a45c254e-df1c-4efd-8020-67d146a850e0}'), pid=32)
DEVPKEY_Device_RemovalPolicy: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{a45c254e-df1c-4efd-8020-67d146a850e0}'), pid=33)
DEVPKEY_Device_RemovalPolicyDefault: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{a45c254e-df1c-4efd-8020-67d146a850e0}'), pid=34)
DEVPKEY_Device_RemovalPolicyOverride: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{a45c254e-df1c-4efd-8020-67d146a850e0}'), pid=35)
DEVPKEY_Device_InstallState: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{a45c254e-df1c-4efd-8020-67d146a850e0}'), pid=36)
DEVPKEY_Device_LocationPaths: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{a45c254e-df1c-4efd-8020-67d146a850e0}'), pid=37)
DEVPKEY_Device_BaseContainerId: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{a45c254e-df1c-4efd-8020-67d146a850e0}'), pid=38)
DEVPKEY_Device_InstanceId: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{78c34fc8-104a-4aca-9ea4-524d52996e57}'), pid=256)
DEVPKEY_Device_DevNodeStatus: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{4340a6c5-93fa-4706-972c-7b648008a5a7}'), pid=2)
DEVPKEY_Device_ProblemCode: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{4340a6c5-93fa-4706-972c-7b648008a5a7}'), pid=3)
DEVPKEY_Device_EjectionRelations: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{4340a6c5-93fa-4706-972c-7b648008a5a7}'), pid=4)
DEVPKEY_Device_RemovalRelations: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{4340a6c5-93fa-4706-972c-7b648008a5a7}'), pid=5)
DEVPKEY_Device_PowerRelations: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{4340a6c5-93fa-4706-972c-7b648008a5a7}'), pid=6)
DEVPKEY_Device_BusRelations: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{4340a6c5-93fa-4706-972c-7b648008a5a7}'), pid=7)
DEVPKEY_Device_Parent: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{4340a6c5-93fa-4706-972c-7b648008a5a7}'), pid=8)
DEVPKEY_Device_Children: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{4340a6c5-93fa-4706-972c-7b648008a5a7}'), pid=9)
DEVPKEY_Device_Siblings: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{4340a6c5-93fa-4706-972c-7b648008a5a7}'), pid=10)
DEVPKEY_Device_TransportRelations: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{4340a6c5-93fa-4706-972c-7b648008a5a7}'), pid=11)
DEVPKEY_Device_ProblemStatus: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{4340a6c5-93fa-4706-972c-7b648008a5a7}'), pid=12)
DEVPKEY_Device_Reported: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{80497100-8c73-48b9-aad9-ce387e19c56e}'), pid=2)
DEVPKEY_Device_Legacy: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{80497100-8c73-48b9-aad9-ce387e19c56e}'), pid=3)
DEVPKEY_Device_ContainerId: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{8c7ed206-3f8a-4827-b3ab-ae9e1faefc6c}'), pid=2)
DEVPKEY_Device_InLocalMachineContainer: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{8c7ed206-3f8a-4827-b3ab-ae9e1faefc6c}'), pid=4)
DEVPKEY_Device_Model: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{78c34fc8-104a-4aca-9ea4-524d52996e57}'), pid=39)
DEVPKEY_Device_ModelId: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{80d81ea6-7473-4b0c-8216-efc11a2c4c8b}'), pid=2)
DEVPKEY_Device_FriendlyNameAttributes: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{80d81ea6-7473-4b0c-8216-efc11a2c4c8b}'), pid=3)
DEVPKEY_Device_ManufacturerAttributes: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{80d81ea6-7473-4b0c-8216-efc11a2c4c8b}'), pid=4)
DEVPKEY_Device_PresenceNotForDevice: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{80d81ea6-7473-4b0c-8216-efc11a2c4c8b}'), pid=5)
DEVPKEY_Device_SignalStrength: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{80d81ea6-7473-4b0c-8216-efc11a2c4c8b}'), pid=6)
DEVPKEY_Device_IsAssociateableByUserAction: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{80d81ea6-7473-4b0c-8216-efc11a2c4c8b}'), pid=7)
DEVPKEY_Device_ShowInUninstallUI: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{80d81ea6-7473-4b0c-8216-efc11a2c4c8b}'), pid=8)
DEVPKEY_Device_CompanionApps: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{6a742654-d0b2-4420-a523-e068352ac1df}'), pid=2)
DEVPKEY_Device_PrimaryCompanionApp: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{6a742654-d0b2-4420-a523-e068352ac1df}'), pid=3)
DEVPKEY_Device_Numa_Proximity_Domain: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{540b947e-8b40-45bc-a8a2-6a0b894cbda2}'), pid=1)
DEVPKEY_Device_DHP_Rebalance_Policy: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{540b947e-8b40-45bc-a8a2-6a0b894cbda2}'), pid=2)
DEVPKEY_Device_Numa_Node: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{540b947e-8b40-45bc-a8a2-6a0b894cbda2}'), pid=3)
DEVPKEY_Device_BusReportedDeviceDesc: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{540b947e-8b40-45bc-a8a2-6a0b894cbda2}'), pid=4)
DEVPKEY_Device_IsPresent: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{540b947e-8b40-45bc-a8a2-6a0b894cbda2}'), pid=5)
DEVPKEY_Device_HasProblem: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{540b947e-8b40-45bc-a8a2-6a0b894cbda2}'), pid=6)
DEVPKEY_Device_ConfigurationId: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{540b947e-8b40-45bc-a8a2-6a0b894cbda2}'), pid=7)
DEVPKEY_Device_ReportedDeviceIdsHash: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{540b947e-8b40-45bc-a8a2-6a0b894cbda2}'), pid=8)
DEVPKEY_Device_PhysicalDeviceLocation: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{540b947e-8b40-45bc-a8a2-6a0b894cbda2}'), pid=9)
DEVPKEY_Device_BiosDeviceName: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{540b947e-8b40-45bc-a8a2-6a0b894cbda2}'), pid=10)
DEVPKEY_Device_DriverProblemDesc: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{540b947e-8b40-45bc-a8a2-6a0b894cbda2}'), pid=11)
DEVPKEY_Device_DebuggerSafe: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{540b947e-8b40-45bc-a8a2-6a0b894cbda2}'), pid=12)
DEVPKEY_Device_PostInstallInProgress: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{540b947e-8b40-45bc-a8a2-6a0b894cbda2}'), pid=13)
DEVPKEY_Device_Stack: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{540b947e-8b40-45bc-a8a2-6a0b894cbda2}'), pid=14)
DEVPKEY_Device_ExtendedConfigurationIds: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{540b947e-8b40-45bc-a8a2-6a0b894cbda2}'), pid=15)
DEVPKEY_Device_IsRebootRequired: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{540b947e-8b40-45bc-a8a2-6a0b894cbda2}'), pid=16)
DEVPKEY_Device_FirmwareDate: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{540b947e-8b40-45bc-a8a2-6a0b894cbda2}'), pid=17)
DEVPKEY_Device_FirmwareVersion: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{540b947e-8b40-45bc-a8a2-6a0b894cbda2}'), pid=18)
DEVPKEY_Device_FirmwareRevision: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{540b947e-8b40-45bc-a8a2-6a0b894cbda2}'), pid=19)
DEVPKEY_Device_DependencyProviders: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{540b947e-8b40-45bc-a8a2-6a0b894cbda2}'), pid=20)
DEVPKEY_Device_DependencyDependents: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{540b947e-8b40-45bc-a8a2-6a0b894cbda2}'), pid=21)
DEVPKEY_Device_SoftRestartSupported: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{540b947e-8b40-45bc-a8a2-6a0b894cbda2}'), pid=22)
DEVPKEY_Device_ExtendedAddress: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{540b947e-8b40-45bc-a8a2-6a0b894cbda2}'), pid=23)
DEVPKEY_Device_AssignedToGuest: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{540b947e-8b40-45bc-a8a2-6a0b894cbda2}'), pid=24)
DEVPKEY_Device_CreatorProcessId: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{540b947e-8b40-45bc-a8a2-6a0b894cbda2}'), pid=25)
DEVPKEY_Device_FirmwareVendor: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{540b947e-8b40-45bc-a8a2-6a0b894cbda2}'), pid=26)
DEVPKEY_Device_SessionId: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{83da6326-97a6-4088-9453-a1923f573b29}'), pid=6)
DEVPKEY_Device_InstallDate: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{83da6326-97a6-4088-9453-a1923f573b29}'), pid=100)
DEVPKEY_Device_FirstInstallDate: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{83da6326-97a6-4088-9453-a1923f573b29}'), pid=101)
DEVPKEY_Device_LastArrivalDate: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{83da6326-97a6-4088-9453-a1923f573b29}'), pid=102)
DEVPKEY_Device_LastRemovalDate: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{83da6326-97a6-4088-9453-a1923f573b29}'), pid=103)
DEVPKEY_Device_DriverDate: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{a8b865dd-2e3d-4094-ad97-e593a70c75d6}'), pid=2)
DEVPKEY_Device_DriverVersion: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{a8b865dd-2e3d-4094-ad97-e593a70c75d6}'), pid=3)
DEVPKEY_Device_DriverDesc: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{a8b865dd-2e3d-4094-ad97-e593a70c75d6}'), pid=4)
DEVPKEY_Device_DriverInfPath: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{a8b865dd-2e3d-4094-ad97-e593a70c75d6}'), pid=5)
DEVPKEY_Device_DriverInfSection: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{a8b865dd-2e3d-4094-ad97-e593a70c75d6}'), pid=6)
DEVPKEY_Device_DriverInfSectionExt: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{a8b865dd-2e3d-4094-ad97-e593a70c75d6}'), pid=7)
DEVPKEY_Device_MatchingDeviceId: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{a8b865dd-2e3d-4094-ad97-e593a70c75d6}'), pid=8)
DEVPKEY_Device_DriverProvider: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{a8b865dd-2e3d-4094-ad97-e593a70c75d6}'), pid=9)
DEVPKEY_Device_DriverPropPageProvider: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{a8b865dd-2e3d-4094-ad97-e593a70c75d6}'), pid=10)
DEVPKEY_Device_DriverCoInstallers: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{a8b865dd-2e3d-4094-ad97-e593a70c75d6}'), pid=11)
DEVPKEY_Device_ResourcePickerTags: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{a8b865dd-2e3d-4094-ad97-e593a70c75d6}'), pid=12)
DEVPKEY_Device_ResourcePickerExceptions: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{a8b865dd-2e3d-4094-ad97-e593a70c75d6}'), pid=13)
DEVPKEY_Device_DriverRank: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{a8b865dd-2e3d-4094-ad97-e593a70c75d6}'), pid=14)
DEVPKEY_Device_DriverLogoLevel: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{a8b865dd-2e3d-4094-ad97-e593a70c75d6}'), pid=15)
DEVPKEY_Device_NoConnectSound: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{a8b865dd-2e3d-4094-ad97-e593a70c75d6}'), pid=17)
DEVPKEY_Device_GenericDriverInstalled: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{a8b865dd-2e3d-4094-ad97-e593a70c75d6}'), pid=18)
DEVPKEY_Device_AdditionalSoftwareRequested: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{a8b865dd-2e3d-4094-ad97-e593a70c75d6}'), pid=19)
DEVPKEY_Device_SafeRemovalRequired: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{afd97640-86a3-4210-b67c-289c41aabe55}'), pid=2)
DEVPKEY_Device_SafeRemovalRequiredOverride: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{afd97640-86a3-4210-b67c-289c41aabe55}'), pid=3)
DEVPKEY_DrvPkg_Model: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{cf73bb51-3abf-44a2-85e0-9a3dc7a12132}'), pid=2)
DEVPKEY_DrvPkg_VendorWebSite: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{cf73bb51-3abf-44a2-85e0-9a3dc7a12132}'), pid=3)
DEVPKEY_DrvPkg_DetailedDescription: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{cf73bb51-3abf-44a2-85e0-9a3dc7a12132}'), pid=4)
DEVPKEY_DrvPkg_DocumentationLink: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{cf73bb51-3abf-44a2-85e0-9a3dc7a12132}'), pid=5)
DEVPKEY_DrvPkg_Icon: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{cf73bb51-3abf-44a2-85e0-9a3dc7a12132}'), pid=6)
DEVPKEY_DrvPkg_BrandingIcon: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{cf73bb51-3abf-44a2-85e0-9a3dc7a12132}'), pid=7)
DEVPKEY_DeviceClass_UpperFilters: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{4321918b-f69e-470d-a5de-4d88c75ad24b}'), pid=19)
DEVPKEY_DeviceClass_LowerFilters: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{4321918b-f69e-470d-a5de-4d88c75ad24b}'), pid=20)
DEVPKEY_DeviceClass_Security: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{4321918b-f69e-470d-a5de-4d88c75ad24b}'), pid=25)
DEVPKEY_DeviceClass_SecuritySDS: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{4321918b-f69e-470d-a5de-4d88c75ad24b}'), pid=26)
DEVPKEY_DeviceClass_DevType: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{4321918b-f69e-470d-a5de-4d88c75ad24b}'), pid=27)
DEVPKEY_DeviceClass_Exclusive: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{4321918b-f69e-470d-a5de-4d88c75ad24b}'), pid=28)
DEVPKEY_DeviceClass_Characteristics: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{4321918b-f69e-470d-a5de-4d88c75ad24b}'), pid=29)
DEVPKEY_DeviceClass_Name: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{259abffc-50a7-47ce-af08-68c9a7d73366}'), pid=2)
DEVPKEY_DeviceClass_ClassName: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{259abffc-50a7-47ce-af08-68c9a7d73366}'), pid=3)
DEVPKEY_DeviceClass_Icon: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{259abffc-50a7-47ce-af08-68c9a7d73366}'), pid=4)
DEVPKEY_DeviceClass_ClassInstaller: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{259abffc-50a7-47ce-af08-68c9a7d73366}'), pid=5)
DEVPKEY_DeviceClass_PropPageProvider: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{259abffc-50a7-47ce-af08-68c9a7d73366}'), pid=6)
DEVPKEY_DeviceClass_NoInstallClass: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{259abffc-50a7-47ce-af08-68c9a7d73366}'), pid=7)
DEVPKEY_DeviceClass_NoDisplayClass: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{259abffc-50a7-47ce-af08-68c9a7d73366}'), pid=8)
DEVPKEY_DeviceClass_SilentInstall: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{259abffc-50a7-47ce-af08-68c9a7d73366}'), pid=9)
DEVPKEY_DeviceClass_NoUseClass: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{259abffc-50a7-47ce-af08-68c9a7d73366}'), pid=10)
DEVPKEY_DeviceClass_DefaultService: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{259abffc-50a7-47ce-af08-68c9a7d73366}'), pid=11)
DEVPKEY_DeviceClass_IconPath: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{259abffc-50a7-47ce-af08-68c9a7d73366}'), pid=12)
DEVPKEY_DeviceClass_DHPRebalanceOptOut: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{d14d3ef3-66cf-4ba2-9d38-0ddb37ab4701}'), pid=2)
DEVPKEY_DeviceClass_ClassCoInstallers: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{713d1703-a2e2-49f5-9214-56472ef3da5c}'), pid=2)
DEVPKEY_DeviceInterface_FriendlyName: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{026e516e-b814-414b-83cd-856d6fef4822}'), pid=2)
DEVPKEY_DeviceInterface_Enabled: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{026e516e-b814-414b-83cd-856d6fef4822}'), pid=3)
DEVPKEY_DeviceInterface_ClassGuid: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{026e516e-b814-414b-83cd-856d6fef4822}'), pid=4)
DEVPKEY_DeviceInterface_ReferenceString: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{026e516e-b814-414b-83cd-856d6fef4822}'), pid=5)
DEVPKEY_DeviceInterface_Restricted: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{026e516e-b814-414b-83cd-856d6fef4822}'), pid=6)
DEVPKEY_DeviceInterface_UnrestrictedAppCapabilities: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{026e516e-b814-414b-83cd-856d6fef4822}'), pid=8)
DEVPKEY_DeviceInterface_SchematicName: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{026e516e-b814-414b-83cd-856d6fef4822}'), pid=9)
DEVPKEY_DeviceInterfaceClass_DefaultInterface: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{14c83a99-0b3f-44b7-be4c-a178d3990564}'), pid=2)
DEVPKEY_DeviceInterfaceClass_Name: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{14c83a99-0b3f-44b7-be4c-a178d3990564}'), pid=3)
DEVPKEY_DeviceContainer_Address: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{78c34fc8-104a-4aca-9ea4-524d52996e57}'), pid=51)
DEVPKEY_DeviceContainer_DiscoveryMethod: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{78c34fc8-104a-4aca-9ea4-524d52996e57}'), pid=52)
DEVPKEY_DeviceContainer_IsEncrypted: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{78c34fc8-104a-4aca-9ea4-524d52996e57}'), pid=53)
DEVPKEY_DeviceContainer_IsAuthenticated: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{78c34fc8-104a-4aca-9ea4-524d52996e57}'), pid=54)
DEVPKEY_DeviceContainer_IsConnected: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{78c34fc8-104a-4aca-9ea4-524d52996e57}'), pid=55)
DEVPKEY_DeviceContainer_IsPaired: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{78c34fc8-104a-4aca-9ea4-524d52996e57}'), pid=56)
DEVPKEY_DeviceContainer_Icon: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{78c34fc8-104a-4aca-9ea4-524d52996e57}'), pid=57)
DEVPKEY_DeviceContainer_Version: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{78c34fc8-104a-4aca-9ea4-524d52996e57}'), pid=65)
DEVPKEY_DeviceContainer_Last_Seen: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{78c34fc8-104a-4aca-9ea4-524d52996e57}'), pid=66)
DEVPKEY_DeviceContainer_Last_Connected: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{78c34fc8-104a-4aca-9ea4-524d52996e57}'), pid=67)
DEVPKEY_DeviceContainer_IsShowInDisconnectedState: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{78c34fc8-104a-4aca-9ea4-524d52996e57}'), pid=68)
DEVPKEY_DeviceContainer_IsLocalMachine: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{78c34fc8-104a-4aca-9ea4-524d52996e57}'), pid=70)
DEVPKEY_DeviceContainer_MetadataPath: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{78c34fc8-104a-4aca-9ea4-524d52996e57}'), pid=71)
DEVPKEY_DeviceContainer_IsMetadataSearchInProgress: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{78c34fc8-104a-4aca-9ea4-524d52996e57}'), pid=72)
DEVPKEY_DeviceContainer_MetadataChecksum: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{78c34fc8-104a-4aca-9ea4-524d52996e57}'), pid=73)
DEVPKEY_DeviceContainer_IsNotInterestingForDisplay: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{78c34fc8-104a-4aca-9ea4-524d52996e57}'), pid=74)
DEVPKEY_DeviceContainer_LaunchDeviceStageOnDeviceConnect: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{78c34fc8-104a-4aca-9ea4-524d52996e57}'), pid=76)
DEVPKEY_DeviceContainer_LaunchDeviceStageFromExplorer: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{78c34fc8-104a-4aca-9ea4-524d52996e57}'), pid=77)
DEVPKEY_DeviceContainer_BaselineExperienceId: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{78c34fc8-104a-4aca-9ea4-524d52996e57}'), pid=78)
DEVPKEY_DeviceContainer_IsDeviceUniquelyIdentifiable: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{78c34fc8-104a-4aca-9ea4-524d52996e57}'), pid=79)
DEVPKEY_DeviceContainer_AssociationArray: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{78c34fc8-104a-4aca-9ea4-524d52996e57}'), pid=80)
DEVPKEY_DeviceContainer_DeviceDescription1: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{78c34fc8-104a-4aca-9ea4-524d52996e57}'), pid=81)
DEVPKEY_DeviceContainer_DeviceDescription2: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{78c34fc8-104a-4aca-9ea4-524d52996e57}'), pid=82)
DEVPKEY_DeviceContainer_HasProblem: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{78c34fc8-104a-4aca-9ea4-524d52996e57}'), pid=83)
DEVPKEY_DeviceContainer_IsSharedDevice: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{78c34fc8-104a-4aca-9ea4-524d52996e57}'), pid=84)
DEVPKEY_DeviceContainer_IsNetworkDevice: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{78c34fc8-104a-4aca-9ea4-524d52996e57}'), pid=85)
DEVPKEY_DeviceContainer_IsDefaultDevice: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{78c34fc8-104a-4aca-9ea4-524d52996e57}'), pid=86)
DEVPKEY_DeviceContainer_MetadataCabinet: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{78c34fc8-104a-4aca-9ea4-524d52996e57}'), pid=87)
DEVPKEY_DeviceContainer_RequiresPairingElevation: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{78c34fc8-104a-4aca-9ea4-524d52996e57}'), pid=88)
DEVPKEY_DeviceContainer_ExperienceId: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{78c34fc8-104a-4aca-9ea4-524d52996e57}'), pid=89)
DEVPKEY_DeviceContainer_Category: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{78c34fc8-104a-4aca-9ea4-524d52996e57}'), pid=90)
DEVPKEY_DeviceContainer_Category_Desc_Singular: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{78c34fc8-104a-4aca-9ea4-524d52996e57}'), pid=91)
DEVPKEY_DeviceContainer_Category_Desc_Plural: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{78c34fc8-104a-4aca-9ea4-524d52996e57}'), pid=92)
DEVPKEY_DeviceContainer_Category_Icon: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{78c34fc8-104a-4aca-9ea4-524d52996e57}'), pid=93)
DEVPKEY_DeviceContainer_CategoryGroup_Desc: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{78c34fc8-104a-4aca-9ea4-524d52996e57}'), pid=94)
DEVPKEY_DeviceContainer_CategoryGroup_Icon: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{78c34fc8-104a-4aca-9ea4-524d52996e57}'), pid=95)
DEVPKEY_DeviceContainer_PrimaryCategory: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{78c34fc8-104a-4aca-9ea4-524d52996e57}'), pid=97)
DEVPKEY_DeviceContainer_UnpairUninstall: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{78c34fc8-104a-4aca-9ea4-524d52996e57}'), pid=98)
DEVPKEY_DeviceContainer_RequiresUninstallElevation: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{78c34fc8-104a-4aca-9ea4-524d52996e57}'), pid=99)
DEVPKEY_DeviceContainer_DeviceFunctionSubRank: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{78c34fc8-104a-4aca-9ea4-524d52996e57}'), pid=100)
DEVPKEY_DeviceContainer_AlwaysShowDeviceAsConnected: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{78c34fc8-104a-4aca-9ea4-524d52996e57}'), pid=101)
DEVPKEY_DeviceContainer_ConfigFlags: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{78c34fc8-104a-4aca-9ea4-524d52996e57}'), pid=105)
DEVPKEY_DeviceContainer_PrivilegedPackageFamilyNames: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{78c34fc8-104a-4aca-9ea4-524d52996e57}'), pid=106)
DEVPKEY_DeviceContainer_CustomPrivilegedPackageFamilyNames: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{78c34fc8-104a-4aca-9ea4-524d52996e57}'), pid=107)
DEVPKEY_DeviceContainer_IsRebootRequired: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{78c34fc8-104a-4aca-9ea4-524d52996e57}'), pid=108)
DEVPKEY_DeviceContainer_FriendlyName: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{656a3bb3-ecc0-43fd-8477-4ae0404a96cd}'), pid=12288)
DEVPKEY_DeviceContainer_Manufacturer: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{656a3bb3-ecc0-43fd-8477-4ae0404a96cd}'), pid=8192)
DEVPKEY_DeviceContainer_ModelName: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{656a3bb3-ecc0-43fd-8477-4ae0404a96cd}'), pid=8194)
DEVPKEY_DeviceContainer_ModelNumber: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{656a3bb3-ecc0-43fd-8477-4ae0404a96cd}'), pid=8195)
DEVPKEY_DeviceContainer_InstallInProgress: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{83da6326-97a6-4088-9453-a1923f573b29}'), pid=9)
DEVPKEY_DevQuery_ObjectType: win32more.Windows.Win32.Foundation.DEVPROPKEY = ConstantLazyLoader(fmtid=Guid('{13673f42-a3d6-49f6-b4da-ae46e0c5237c}'), pid=2)
MAX_DEVPROP_TYPE: UInt32 = 25
MAX_DEVPROP_TYPEMOD: UInt32 = 8192
DEVPROP_MASK_TYPE: UInt32 = 4095
DEVPROP_MASK_TYPEMOD: UInt32 = 61440
DEVPROPID_FIRST_USABLE: UInt32 = 2
class DEVPROPCOMPKEY(Structure):
    Key: win32more.Windows.Win32.Foundation.DEVPROPKEY
    Store: win32more.Windows.Win32.Devices.Properties.DEVPROPSTORE
    LocaleName: win32more.Windows.Win32.Foundation.PWSTR
class DEVPROPERTY(Structure):
    CompKey: win32more.Windows.Win32.Devices.Properties.DEVPROPCOMPKEY
    Type: win32more.Windows.Win32.Devices.Properties.DEVPROPTYPE
    BufferSize: UInt32
    Buffer: VoidPtr
DEVPROPSTORE = Int32
DEVPROP_STORE_SYSTEM: win32more.Windows.Win32.Devices.Properties.DEVPROPSTORE = 0
DEVPROP_STORE_USER: win32more.Windows.Win32.Devices.Properties.DEVPROPSTORE = 1
DEVPROPTYPE = UInt32
DEVPROP_TYPEMOD_ARRAY: win32more.Windows.Win32.Devices.Properties.DEVPROPTYPE = 4096
DEVPROP_TYPEMOD_LIST: win32more.Windows.Win32.Devices.Properties.DEVPROPTYPE = 8192
DEVPROP_TYPE_EMPTY: win32more.Windows.Win32.Devices.Properties.DEVPROPTYPE = 0
DEVPROP_TYPE_NULL: win32more.Windows.Win32.Devices.Properties.DEVPROPTYPE = 1
DEVPROP_TYPE_SBYTE: win32more.Windows.Win32.Devices.Properties.DEVPROPTYPE = 2
DEVPROP_TYPE_BYTE: win32more.Windows.Win32.Devices.Properties.DEVPROPTYPE = 3
DEVPROP_TYPE_INT16: win32more.Windows.Win32.Devices.Properties.DEVPROPTYPE = 4
DEVPROP_TYPE_UINT16: win32more.Windows.Win32.Devices.Properties.DEVPROPTYPE = 5
DEVPROP_TYPE_INT32: win32more.Windows.Win32.Devices.Properties.DEVPROPTYPE = 6
DEVPROP_TYPE_UINT32: win32more.Windows.Win32.Devices.Properties.DEVPROPTYPE = 7
DEVPROP_TYPE_INT64: win32more.Windows.Win32.Devices.Properties.DEVPROPTYPE = 8
DEVPROP_TYPE_UINT64: win32more.Windows.Win32.Devices.Properties.DEVPROPTYPE = 9
DEVPROP_TYPE_FLOAT: win32more.Windows.Win32.Devices.Properties.DEVPROPTYPE = 10
DEVPROP_TYPE_DOUBLE: win32more.Windows.Win32.Devices.Properties.DEVPROPTYPE = 11
DEVPROP_TYPE_DECIMAL: win32more.Windows.Win32.Devices.Properties.DEVPROPTYPE = 12
DEVPROP_TYPE_GUID: win32more.Windows.Win32.Devices.Properties.DEVPROPTYPE = 13
DEVPROP_TYPE_CURRENCY: win32more.Windows.Win32.Devices.Properties.DEVPROPTYPE = 14
DEVPROP_TYPE_DATE: win32more.Windows.Win32.Devices.Properties.DEVPROPTYPE = 15
DEVPROP_TYPE_FILETIME: win32more.Windows.Win32.Devices.Properties.DEVPROPTYPE = 16
DEVPROP_TYPE_BOOLEAN: win32more.Windows.Win32.Devices.Properties.DEVPROPTYPE = 17
DEVPROP_TYPE_STRING: win32more.Windows.Win32.Devices.Properties.DEVPROPTYPE = 18
DEVPROP_TYPE_STRING_LIST: win32more.Windows.Win32.Devices.Properties.DEVPROPTYPE = 8210
DEVPROP_TYPE_SECURITY_DESCRIPTOR: win32more.Windows.Win32.Devices.Properties.DEVPROPTYPE = 19
DEVPROP_TYPE_SECURITY_DESCRIPTOR_STRING: win32more.Windows.Win32.Devices.Properties.DEVPROPTYPE = 20
DEVPROP_TYPE_DEVPROPKEY: win32more.Windows.Win32.Devices.Properties.DEVPROPTYPE = 21
DEVPROP_TYPE_DEVPROPTYPE: win32more.Windows.Win32.Devices.Properties.DEVPROPTYPE = 22
DEVPROP_TYPE_BINARY: win32more.Windows.Win32.Devices.Properties.DEVPROPTYPE = 4099
DEVPROP_TYPE_ERROR: win32more.Windows.Win32.Devices.Properties.DEVPROPTYPE = 23
DEVPROP_TYPE_NTSTATUS: win32more.Windows.Win32.Devices.Properties.DEVPROPTYPE = 24
DEVPROP_TYPE_STRING_INDIRECT: win32more.Windows.Win32.Devices.Properties.DEVPROPTYPE = 25
DEVPROP_BOOLEAN = Byte


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.Security
import win32more.Windows.Win32.System.Com
import win32more.Windows.Win32.System.WinRT
import win32more.Windows.Win32.System.WinRT.Display
class IDisplayDeviceInterop(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{64338358-366a-471b-bd56-dd8ef48e439b}')
    @commethod(3)
    def CreateSharedHandle(self, pObject: win32more.Windows.Win32.System.WinRT.IInspectable, pSecurityAttributes: POINTER(win32more.Windows.Win32.Security.SECURITY_ATTRIBUTES), Access: UInt32, Name: win32more.Windows.Win32.System.WinRT.HSTRING, pHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def OpenSharedHandle(self, NTHandle: win32more.Windows.Win32.Foundation.HANDLE, riid: Guid, ppvObj: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDisplayPathInterop(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{a6ba4205-e59e-4e71-b25b-4e436d21ee3d}')
    @commethod(3)
    def CreateSourcePresentationHandle(self, pValue: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetSourceId(self, pSourceId: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...


make_ready(__name__)
